// compile-flags:--test -Z unstable-options
// edition:2018

/// ```rust
/// fn main() {
///     let _ = async { };
/// }
/// ```
fn main() {
    let _ = async { };
}
